# HeimdallAuth
This makes it easy to equip an empty rails application with our Heimdall Auth features.

## Installation and Usage

Example: https://gitlab.vesputi.com/netzmap/nanna

0) Commit the empty rails application (and mention the command you used for generating the app)

1) Add this line to your application's Gemfile:

```ruby
gem 'heimdall_auth'
```

2) and afterwards do theses commands (yes... second bundle install ist needed, because the install script adds dotenv gem)
```bash
bundle install
rails puma_dev:link
rails generate heimdall_auth:install
rails heimdall:register -- -u"rene@vesputi.com" -p"HeimdallPassword" >> .env
bundle install
killall puma-dev
```

3) And please commit directly after executing the lines above so you have clean history


## Linking puma_dev

This executes a very simple `ln -s` command in order to link our application with appropriate naming to the local puma_dev server.
```bash
rails puma_dev:link
```

## Heimdall-Auth install scripts
This makes a few steps in order to install heimdall stuff to your app.
```bash
rails generate heimdall_auth:install
```
executes the following generators
1. `rails generate heimdall_auth:cancan`
2. `rails generate heimdall_auth:sessions`
3. `rails generate heimdall_auth:standard_pages`
4. `rails generate heimdall_auth:dotenv`

### generate heimdall_auth:cancan
This adds the ability.rb file of the cancancan gem with default heimdall roles and adds `check_authorization` to the application controller. (For details see the [cancancan gem](https://github.com/CanCanCommunity/cancancan))

### generate heimdall_auth:sessions
This adds the default heimdall_auth routes for session generation to the routes file, switches the application to https only and lowers the log level.

### generate heimdall_auth:standard_pages
This adds the default admin page `/admin` and two error pages: for invalid_user_data and not_enough_rights.

### generate heimdall_auth:dotenv
This adds a default .env.example file (for documentation purposes) to the application and adds the dotenv gem to the gemfile which loads enviroment variables from .env file.

## Register at local heimdall

The following command Registeres the service at Heimdall and puts credentials at the end of the `.env` file

```bash
rails heimdall:register -- -u"rene@vesputi.com" -p"YourHeimdallPassword" >> .env
```
Parameters:
```
-u"rene@vesputi.com" # Username in Heimdall (Needs Admin rights)
-p"YourHeimdallPassword" # Password in Heimdall
-h"https://heimdall.vesp" (Optional) - Protocol and Domain the heimdall is found at
-s"https://foo.vesputi-abc.de" # (Optional) - Protocol and Domain the Service is found at
```

## RSpec
If you want to test your Applications controller than you have to give it a User
You do so by mocking `current_user` in ApplicationController

```
RSpec.describe "/foobar", type: :request do
  before { allow_any_instance_of(ApplicationController).to receive(:current_user) { HeimdallAuth::User.new(is_editor: true) } }
end
```
